@@ -7,8 +7,11 @@
 #pragma once
 
 #include <gio/gio.h>
+#ifdef HAVE_GUSB
 #include <gusb.h>
+#endif
 
+#include "fu-bluez-device.h"
 #include "fu-common.h"
 #include "fu-common-guid.h"
 #include "fu-common-version.h"
@@ -21,8 +24,8 @@
 #ifdef HAVE_GUDEV
 #include "fu-udev-device.h"
 #endif
-#include "fwupd-common.h"
-#include "fwupd-plugin.h"
+#include <libfwupd/fwupd-common.h>
+#include <libfwupd/fwupd-plugin.h>
 
 #define FU_TYPE_PLUGIN (fu_plugin_get_type ())
 G_DECLARE_DERIVABLE_TYPE (FuPlugin, fu_plugin, FU, PLUGIN, FwupdPlugin)
@@ -30,6 +33,7 @@ G_DECLARE_DERIVABLE_TYPE (FuPlugin, fu_plugin, FU, PLUGIN, FwupdPlugin)
 #define fu_plugin_get_flags(p)			fwupd_plugin_get_flags(FWUPD_PLUGIN(p))
 #define fu_plugin_has_flag(p,f)			fwupd_plugin_has_flag(FWUPD_PLUGIN(p),f)
 #define fu_plugin_add_flag(p,f)			fwupd_plugin_add_flag(FWUPD_PLUGIN(p),f)
+#define fu_plugin_remove_flag(p,f)		fwupd_plugin_remove_flag(FWUPD_PLUGIN(p),f)
 
 struct _FuPluginClass
 {
@@ -124,6 +128,8 @@ void		 fu_plugin_set_device_gtype		(FuPlugin	*self,
 void		 fu_plugin_add_firmware_gtype		(FuPlugin	*self,
 							 const gchar	*id,
 							 GType		 gtype);
+void		 fu_plugin_add_possible_quirk_key	(FuPlugin	*self,
+							 const gchar	*possible_key);
 gpointer	 fu_plugin_cache_lookup			(FuPlugin	*self,
 							 const gchar	*id);
 void		 fu_plugin_cache_remove			(FuPlugin	*self,
@@ -135,7 +141,9 @@ gboolean	 fu_plugin_check_hwid			(FuPlugin	*self,
 							 const gchar	*hwid);
 gchar		*fu_plugin_get_hwid_replace_value	(FuPlugin	*self,
 							 const gchar	*keys,
-							 GError		**error);
+							 GError		**error)
+							 G_GNUC_WARN_UNUSED_RESULT;
+GPtrArray	*fu_plugin_get_devices			(FuPlugin	*self);
 GPtrArray	*fu_plugin_get_hwids			(FuPlugin	*self);
 const gchar	*fu_plugin_get_dmi_value		(FuPlugin	*self,
 							 const gchar	*dmi_id);
